# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-06-16 04:20
from __future__ import unicode_literals

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('bom', '0001_squashed_0018_auto_20170418_0330'),
    ]

    operations = [
        migrations.AlterField(
            model_name='usermeta',
            name='organization',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='bom.Organization'),
        ),
    ]
